/*
 * Copyright (c) 2019-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.scanner.json.format;

import com.google.gson.annotations.SerializedName;

import org.hedgecode.chess.scanner.format.ArenaFormat;
import org.hedgecode.chess.scanner.format.IndexData;
import org.hedgecode.chess.scanner.format.Room;

/**
 * JSONArenaFormat
 *
 * @author Dmitry Samoshin aka gotty
 */
public class JSONArenaFormat extends AbstractBaseFormat implements ArenaFormat {

    @SerializedName("indexData")
    private JSONIndexData indexData;

    JSONArenaFormat() {
    }

    @Override
    public IndexData indexData() {
        return indexData;
    }

    @Override
    public String findTournament(String tournamentName) {
        for (Room room : indexData.rooms()) {
            if (room.name().contains(tournamentName)) {
                return room.slug();
            }
        }
        return null;
    }

}
