/*
 * Copyright (c) 2019-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.scanner.json.format;

import com.google.gson.annotations.SerializedName;

import org.hedgecode.chess.scanner.format.Game;
import org.hedgecode.chess.scanner.format.GameData;
import org.hedgecode.chess.scanner.format.Move;
import org.hedgecode.chess.scanner.format.Room;

/**
 * JSONGameData
 *
 * @author Dmitry Samoshin aka gotty
 */
public class JSONGameData implements GameData {

    private static final String WHITE_MOVE_FORMAT = "%d. %s ";
    private static final String BLACK_MOVE_FORMAT = "%s ";

    @SerializedName("game")
    private JSONGame game;

    @SerializedName("room")
    private JSONRoom room;

    @SerializedName("moves")
    private JSONMove[] moves;

    JSONGameData() {
    }

    @Override
    public Game game() {
        return game;
    }

    @Override
    public Room room() {
        return room;
    }

    @Override
    public Move[] moves() {
        return moves;
    }

    @Override
    public String formatMoves() {
        StringBuilder sb = new StringBuilder();
        for (Move move : moves) {
            if (move.number() % 2 == 0) {
                sb.append(
                        String.format(WHITE_MOVE_FORMAT, move.number() / 2 + 1, move.move())
                );
            } else {
                sb.append(
                        String.format(BLACK_MOVE_FORMAT, move.move())
                );
            }
        }
        return sb.toString();
    }

}
