/*
 * Copyright (c) 2019-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.scanner.json.format;

import java.util.ArrayList;
import java.util.List;

import com.google.gson.annotations.SerializedName;

import org.hedgecode.chess.scanner.format.Game;
import org.hedgecode.chess.scanner.format.RoomData;
import org.hedgecode.chess.scanner.format.TournamentFormat;

/**
 * JSONTournamentFormat
 *
 * @author Dmitry Samoshin aka gotty
 */
public class JSONTournamentFormat extends AbstractBaseFormat implements TournamentFormat {

    private static final String GAME_URL_FORMAT = "%s-%s";

    @SerializedName("roomData")
    private JSONRoomData roomData;

    JSONTournamentFormat() {
    }

    @Override
    public String id() {
        return Integer.toString(
                roomData().room().id()
        );
    }

    @Override
    public String name() {
        return roomData().room().name();
    }

    @Override
    public RoomData roomData() {
        return roomData;
    }

    @Override
    public List<String> gameUrls() {
        List<String> gameUrls = new ArrayList<>();
        for (Game game : roomData.games()) {
            gameUrls.add(
                    String.format(GAME_URL_FORMAT, game.roundSlug(), game.slug())
            );
        }
        return gameUrls;
    }

}
