/*
 * Copyright (c) 2019-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.scanner.spi;

import java.util.Iterator;
import java.util.ServiceLoader;

/**
 * Service Provider Interface (SPI) Registry.
 *
 * @author Dmitry Samoshin aka gotty
 */
public final class ServiceRegistry {

    private ServiceRegistry() {
    }

    public static <ServiceType> ServiceType singleProvider(Class<ServiceType> serviceClass) {
        final Iterator<ServiceType> providers = providers(serviceClass);

        ServiceType provider = providers.next();
        if (providers.hasNext()) {
            throw new ServiceRegistryException(
                    String.format("Too many service providers for: %s", serviceClass.getName())
            );
        }

        return provider;
    }

    private static <ServiceType> Iterator<ServiceType> providers(Class<ServiceType> serviceClass) {
        final Iterator<ServiceType> providers = ServiceLoader.load(serviceClass).iterator();

        if (!providers.hasNext()) {
            throw new ServiceRegistryException(
                    String.format("Service provider not found for: %s", serviceClass.getName())
            );
        }

        return providers;
    }

}
